Simple

Struct Simple 

pub struct Simple(/* private fields */);
Format a Yyid as a simple string, like c49b79f522d4dc42f214f4209c80d048.

Implementations

Source

impl Simple

pub const fn from_yyid(yyid: Yyid) -> Self

Wraps a Yyid into a Simple

pub const fn as_yyid(&self) -> &Yyid

Get a reference to the underlying Yyid.

pub const fn into_yyid(self) -> Yyid

Consumes the Simple, returning the underlying Yyid.

pub fn encode_lower<'buf>(&self, buffer: &'buf mut [u8]) -> &'buf mut str

Writes the Yyid as a lower-case simple string to buffer, and returns the subslice of the buffer that contains the encoded YYID.

pub fn encode_upper<'buf>(&self, buffer: &'buf mut [u8]) -> &'buf mut str

Writes the Yyid as a upper-case simple string to buffer, and returns the subslice of the buffer that contains the encoded YYID.